# Copyright (C) 2008-2009, Sebastian Riedel.

package MojoliciousTest::Foo::Bar;

use strict;
use warnings;

use base 'Mojolicious::Controller';

# Poor Bender. Without his brain he's become all quiet and helpful.
sub index { }

1;
